cocos.audio.SDL.version module — cocos v0.6.5 documentation

# cocos.audio.SDL.version module

Functions related to the SDL shared library version.

class `SDL_version`

  Bases: `_ctypes.Structure`

  Version structure.

  Ivariables: | major : int Major version number minor : int Minor version number patch : int Patch revision number

  `is_since`(required)
  `major`

    Structure/Union member

  `minor`

    Structure/Union member

  `patch`

    Structure/Union member

`SDL_VERSIONNUM`(major, minor, patch)

  Turn the version numbers into a numeric value.

  For example:

      >>> SDL_VERSIONNUM(1, 2, 3)
      1203

  Parameters: | major: int minor: int patch: int
  Return type: | int

`SDL_VERSION_ATLEAST`(major, minor, patch)

  Determine if the SDL library is at least the given version.

  Parameters: | major: int minor: int patch: int
  Return type: | bool